@@ -1,3 +1,16 @@
+###############
+# just to use the torch's version of these classes, to help with imports are imported here
+#module
+from torch.nn import Module
+
+#containers
+from torch.nn import Container, Sequential, ModuleList, ModuleDict, ParameterList, ParameterDict 
+
+#padding
+from torch.nn import ReflectionPad1d, ReflectionPad2d, ReplicationPad1d, ReplicationPad2d, \
+                    ReplicationPad3d, ZeroPad2d, ConstantPad1d, ConstantPad2d, ConstantPad3d
+###############
+
 from .linear import Identity, Linear, Bilinear
 from .conv import Conv1d, Conv2d, Conv3d, \
     ConvTranspose1d, ConvTranspose2d, ConvTranspose3d
@@ -8,4 +21,4 @@ from .pooling import AvgPool1d, AvgPool2d, AvgPool3d, MaxPool1d, MaxPool2d, MaxP
     AdaptiveMaxPool1d, AdaptiveMaxPool2d, AdaptiveMaxPool3d, AdaptiveAvgPool1d, AdaptiveAvgPool2d, AdaptiveAvgPool3d
 from .batchnorm import BatchNorm1d, BatchNorm2d, BatchNorm3d
 from .dropout import Dropout, Dropout2d, Dropout3d, AlphaDropout, FeatureAlphaDropout
-from .upsampling import Upsample
+from .upsampling import Upsample
\ No newline at end of file
